# Quat_to_euler
Adds a quaternion-to-Euler Unity-like method to numpy-quaternion module.


Originally based on code by Mike Boyle ("https://github.com/moble/quaternion")


The basic requirements for this code are current versions of python, numpy and 
moble numpy-quaternion.


## Quick install

```sh
pip install --user quat_to_euler
```
